#[non_exhaustive]pub enum BinPackingError {
InvalidInput(String),
Unsupported(String),
Infeasible1D {
item: String,
length: u32,
},
Infeasible2D {
item: String,
width: u32,
height: u32,
},
Infeasible3D {
item: String,
width: u32,
height: u32,
depth: u32,
},
}Expand description
Errors returned by the bin-packing solvers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidInput(String)
The problem failed input validation (e.g. empty demand list, zero dimension, invalid cost).
Unsupported(String)
The requested solver configuration is not currently supported.
Infeasible1D
A 1D demand cannot fit any declared stock entry.
Fields
Infeasible2D
A 2D demand cannot fit any declared sheet entry, even with rotation.
Fields
Infeasible3D
A 3D demand cannot fit any declared bin entry, even with rotation.