pub struct BinLayout3D {
pub bin_name: String,
pub width: u32,
pub height: u32,
pub depth: u32,
pub cost: f64,
pub placements: Vec<Placement3D>,
pub used_volume: u64,
pub waste_volume: u64,
}Expand description
A single packed bin layout produced by the solver.
Fields
bin_name: StringName of the bin type consumed by this layout.
width: u32Bin width.
height: u32Bin height.
depth: u32Bin depth.
cost: f64Cost of consuming this bin.
placements: Vec<Placement3D>Boxes placed in this bin.
used_volume: u64Total volume occupied by the placements.
waste_volume: u64Total wasted volume in this bin.