pub struct Sheet2D {
pub name: String,
pub width: u32,
pub height: u32,
pub cost: f64,
pub quantity: Option<usize>,
}Expand description
A sheet stock entry that demands can be placed on.
Fields
name: StringHuman-readable identifier for this sheet type.
width: u32Sheet width.
height: u32Sheet height.
cost: f64Per-unit cost of consuming a sheet of this type.
quantity: Option<usize>Optional cap on the number of sheets of this type that may be used.