pub struct SheetLayout2D {
pub sheet_name: String,
pub width: u32,
pub height: u32,
pub cost: f64,
pub placements: Vec<Placement2D>,
pub used_area: u64,
pub waste_area: u64,
}Expand description
A single packed sheet layout produced by the solver.
Fields
sheet_name: StringName of the sheet type consumed by this layout.
width: u32Sheet width.
height: u32Sheet height.
cost: f64Cost of consuming this sheet.
placements: Vec<Placement2D>Rectangles placed on this sheet.
used_area: u64Total area occupied by the placements.
waste_area: u64Total wasted area on this sheet.